@@ -137,9 +137,9 @@ static void easySymbolInput_set_callback(PropertyContext *ctx, GValue *value){
     IBusChewingEngine *engine=(IBusChewingEngine *) ctx->userData;
     chewing_set_easySymbolInput(engine->context,(g_value_get_boolean(value)) ? 1: 0);
     if (g_value_get_boolean(value)){
-	engine->flags |= CHEWING_FLAG_EASY_SYMBOL_INPUT;
+	engine->chewingFlags |= CHEWING_FLAG_EASY_SYMBOL_INPUT;
     }else{
-	engine->flags &= ~CHEWING_FLAG_EASY_SYMBOL_INPUT;
+	engine->chewingFlags &= ~CHEWING_FLAG_EASY_SYMBOL_INPUT;
     }
 #endif
 }
@@ -163,9 +163,9 @@ static void forceLowercaseEnglish_set_callback(PropertyContext *ctx, GValue *val
 #ifdef IBUS_CHEWING_MAIN
     IBusChewingEngine *engine=(IBusChewingEngine *) ctx->userData;
     if (g_value_get_boolean(value)){
-	engine->flags |= CHEWING_FLAG_FORCE_LOWERCASE_ENGLISH;
+	engine->chewingFlags |= CHEWING_FLAG_FORCE_LOWERCASE_ENGLISH;
     }else{
-	engine->flags &= ~CHEWING_FLAG_FORCE_LOWERCASE_ENGLISH;
+	engine->chewingFlags &= ~CHEWING_FLAG_FORCE_LOWERCASE_ENGLISH;
     }
 #endif
 }
@@ -188,13 +188,14 @@ static void numpadAlwaysNumber_set_callback(PropertyContext *ctx, GValue *value)
 #ifdef IBUS_CHEWING_MAIN
     IBusChewingEngine *engine=(IBusChewingEngine *) ctx->userData;
     if (g_value_get_boolean(value)){
-	engine->flags |= CHEWING_FLAG_NUMPAD_ALWAYS_NUMBER;
+	engine->chewingFlags |= CHEWING_FLAG_NUMPAD_ALWAYS_NUMBER;
     }else{
-	engine->flags &= ~CHEWING_FLAG_NUMPAD_ALWAYS_NUMBER;
+	engine->chewingFlags &= ~CHEWING_FLAG_NUMPAD_ALWAYS_NUMBER;
     }
 #endif
 }
 
+#if IBUS_VERSION < 10300
 static void inputStyle_set_callback(PropertyContext *ctx, GValue *value){
 #ifdef IBUS_CHEWING_MAIN
     IBusChewingEngine *engine=(IBusChewingEngine *) ctx->userData;
@@ -207,8 +208,9 @@ static void inputStyle_set_callback(PropertyContext *ctx, GValue *value){
 	engine->_priv->inputStyle=CHEWING_INPUT_STYLE_IN_APPLICATION;
     }
     ibus_chewing_engine_force_commit(engine);
-#endif
+#endif /* IBUS_CHEWING_MAIN */
 }
+#endif
 
 static void candPerPage_set_callback(PropertyContext *ctx, GValue *value){
 #ifdef IBUS_CHEWING_MAIN
@@ -241,9 +243,9 @@ static void plainZhuyin_set_callback(PropertyContext *ctx, GValue *value){
 #ifdef IBUS_CHEWING_MAIN
     IBusChewingEngine *engine=(IBusChewingEngine *) ctx->userData;
     if (g_value_get_boolean(value)){
-	engine->flags |= CHEWING_FLAG_PLAIN_ZHUYIN;
+	engine->chewingFlags |= CHEWING_FLAG_PLAIN_ZHUYIN;
     }else{
-	engine->flags &= ~CHEWING_FLAG_PLAIN_ZHUYIN;
+	engine->chewingFlags &= ~CHEWING_FLAG_PLAIN_ZHUYIN;
     }
 #endif
 }
@@ -329,6 +331,13 @@ this option determines how these status be synchronized. Valid values:\n\
 	N_("Always input numbers when number keys from key pad is inputted."),
     },
 
+/*
+ * Input style is decommissioned for ibus 1.3,
+ * because ibus 1.3 has built-in support of input style.
+ * Using built-in input style provides extra benefit,
+ * like typed text won't be lost when focus-out and disable event.
+ */
+#if IBUS_VERSION < 10300
     {G_TYPE_STRING, "inputStyle", "Editing", N_("Input Style"),
 	"in candidate window", inputStyles, NULL,  0, 1,
 	NULL, inputStyle_set_callback,
@@ -338,6 +347,7 @@ this option determines how these status be synchronized. Valid values:\n\
 		"\"in application window\": Preedit strings are edited on the target application window.\n"
 		"\"in candidate window\": Preedit strings are edited on the candidate selection window."),
     },
+#endif
 
     {G_TYPE_BOOLEAN, "plainZhuyin", "Selecting", N_("Plain Zhuyin mode"),
 	"0", NULL, NULL, 0, 1,
@@ -377,6 +387,84 @@ this option determines how these status be synchronized. Valid values:\n\
  */
 #ifdef IBUS_CHEWING_MAIN
 
+#if IBUS_VERSION >= 10399
+void g_variant_to_g_value(GVariant *gVar, GValue *gValue){
+    const GVariantType *gVType=g_variant_get_type(gVar);
+    if (g_variant_type_is_subtype_of(gVType, G_VARIANT_TYPE_BOOLEAN)){
+	g_value_set_boolean(gValue, g_variant_get_boolean(gVar));
+    }else if (g_variant_type_is_subtype_of(gVType, G_VARIANT_TYPE_UINT16)){
+	g_value_set_uint(gValue, g_variant_get_uint16(gVar));
+    }else if (g_variant_type_is_subtype_of(gVType, G_VARIANT_TYPE_UINT32)){
+	g_value_set_uint(gValue, g_variant_get_uint32(gVar));
+    }else if (g_variant_type_is_subtype_of(gVType, G_VARIANT_TYPE_UINT64)){
+	g_value_set_uint64(gValue, g_variant_get_uint64(gVar));
+    }else if (g_variant_type_is_subtype_of(gVType, G_VARIANT_TYPE_INT16)){
+	g_value_set_int(gValue, g_variant_get_int16(gVar));
+    }else if (g_variant_type_is_subtype_of(gVType, G_VARIANT_TYPE_INT32)){
+	g_value_set_int(gValue, g_variant_get_int32(gVar));
+    }else if (g_variant_type_is_subtype_of(gVType, G_VARIANT_TYPE_INT64)){
+	g_value_set_int64(gValue, g_variant_get_int64(gVar));
+    }else if (g_variant_type_is_subtype_of(gVType, G_VARIANT_TYPE_STRING)){
+	g_value_set_int64(gValue, g_variant_get_string(gVar, NULL));
+    }
+}
+
+GVariant *g_value_to_g_variant(GValue *gValue){
+    GType gType=g_value_get_gtype(gValue);
+    GVariant *gVar=NULL;
+    switch(gType){
+	case G_TYPE_BOOLEAN:
+	    gVar=g_variant_new_boolean(g_value_get_boolean(gValue));
+	    break;
+	case G_TYPE_UINT:
+	    gVar=g_variant_new_uint32(g_value_get_uint(gValue));
+	    break;
+	case G_TYPE_INT:
+	    gVar=g_variant_new_int32(g_value_get_int(gValue));
+	    break;
+	case G_TYPE_STRING:
+	    gVar=g_variant_new_string(g_value_get_string(gValue));
+	    break;
+	default:
+	    break;
+    }
+    return gVar;
+}
+
+#endif
+
+static gboolean ibus_chewing_config_get_value(IBusConfig *config, const gchar *section, const gchar *key, GValue *gValue){
+#if IBUS_VERSION >= 10399
+    GVariant *gVar=g_variant_ref_sink(ibus_config_get_value(config, section, key));
+    if (gVar!=NULL){
+	g_variant_to_g_value(gVar, gValue);
+	g_variant_unref(gVar);
+	return TRUE;
+    }else{
+	return FALSE;
+    }
+#else
+    return ibus_config_get_value(config, section, key, gValue);
+#endif
+
+}
+
+static gboolean ibus_chewing_config_set_value(IBusConfig *config, const gchar *section, const gchar *key, GValue *gValue){
+#if IBUS_VERSION >= 10399
+    GVariant *gVar=g_variant_ref_sink(g_value_to_g_variant(gValue));
+    if (gVar!=NULL){
+	return ibus_config_set_value(config, section, key, gVar);
+    }else{
+	return FALSE;
+    }
+#else
+    return ibus_config_set_value(config, section, key, gValue);
+#endif
+
+}
+
+
+
 static guint keysym_KP_to_normal(guint keysym){
     if (keysym < IBUS_KP_0 || keysym > IBUS_KP_9){
 	switch(keysym){
