@@ -34,14 +34,17 @@ static IBusFactory *factory = NULL;
 
 /* options */
 static gboolean ibus = FALSE;
+static gboolean xml = FALSE;
 int ibus_chewing_verbose= 0;
 
+
 static const GOptionEntry entries[] =
 {
     { "ibus", 'i', 0, G_OPTION_ARG_NONE, &ibus, "component is executed by ibus", NULL },
     { "verbose", 'v', 0, G_OPTION_ARG_INT, &ibus_chewing_verbose,
         "Verbose level. The higher the level, the more the debug messages.",
         "[integer]" },
+    { "xml", 'x', 0, G_OPTION_ARG_NONE, &xml, "read chewing engine desc from xml file", NULL },
     { NULL },
 };
 
@@ -58,30 +61,33 @@ ibus_disconnected_cb (IBusBus  *bus,
 static void
 start_component (void)
 {
+    ibus_init();
     bus = ibus_bus_new ();
     g_signal_connect (bus, "disconnected", G_CALLBACK (ibus_disconnected_cb), NULL);
 
-    IBusConnection *iConnection=ibus_bus_get_connection (bus);
-    factory = ibus_factory_new (iConnection);
+    factory = ibus_factory_new (ibus_bus_get_connection (bus));
+
     ibus_factory_add_engine (factory, "chewing", IBUS_TYPE_CHEWING_ENGINE);
 
     if (ibus) {
         ibus_bus_request_name (bus, "org.freedesktop.IBus.Chewing", 0);
     }else {
-        IBusComponent *component;
-//        component = ibus_component_new_from_file ( DATADIR "/ibus/component/chewing.xml");
-        component=ibus_component_new("org.freedesktop.IBus.Chewing",
-                _("Chewing component"), PKGDATADIR, "GPLv2+",
+        IBusComponent *component=NULL;
+        if (xml){
+            component = ibus_component_new_from_file ( DATA_DIR "/ibus/component/chewing.xml");
+        }else{
+            component=ibus_component_new("org.freedesktop.IBus.Chewing",
+                _("Chewing component"), PRJ_VER, "GPLv2+",
                 _("Peng Huang, Ding-Yi Chen"),
                 "http://code.google.com/p/ibus",
                 LIBEXEC_DIR "/ibus-engine-chewing --ibus",
                 "ibus-chewing");
-
+        }
         ibus_component_add_engine(component,
                 ibus_engine_desc_new("chewing", _("Chewing"),
                 "Chinese chewing input method",
                 "zh_TW", "GPLv2+", _("Peng Huang, Ding-Yi Chen"),
-                PKGDATADIR "/icons/" PROJECT_NAME ".png",
+                PRJ_DATA_DIR "/icons/" PROJECT_NAME ".png",
                 "us")
         );
 
@@ -135,7 +141,7 @@ main (gint argc, gchar *argv[])
 
     /* Init i18n messages */
     setlocale (LC_ALL, "zh_TW.utf8");
-    bindtextdomain(PROJECT_NAME, DATADIR "/locale");
+    bindtextdomain(PROJECT_NAME, DATA_DIR "/locale");
     textdomain(PROJECT_NAME);
 
     context = g_option_context_new ("- ibus chewing engine component");
